#[command]Expand description
Generate one typed command’s portable contract and optional executable mount from the same handler declaration.
#[command]Generate one typed command’s portable contract and optional executable mount from the same handler declaration.