Module entity

Module entity 

Structs

BitcodePayloadCodec
Default payload codec.
Entity
EventRecord
Replayable aggregate event record stored in an event-sourced entity stream.
EventRecordError
Error when serializing or deserializing event records.
EventUpcaster
A stateless, pure transformation that converts an event payload from one version to another.
LocalEvent

Enums

UpcastError
Error returned when an upcaster chain cannot make safe forward progress.

Constants

BITCODE_PAYLOAD_CODEC
BITCODE_PAYLOAD_CODEC_VERSION

Traits

Committable
Trait for types that can be committed to a repository.
Event
PayloadCodec
Codec used to serialize and deserialize event payload bytes.

Functions

upcast_events
Apply upcasters to a list of events. Chains automatically (v1->v2->v3).
upcast_payload
Decode an event payload, transform it with typed Rust values, and encode the result.