pub enum MutationAssignment {
Set(MutationExpression),
Unset,
Unknown,
}Expand description
Field assignment that preserves null versus removal versus unknown.
Variants
Set(MutationExpression)
Evaluate and assign a concrete value (including explicit null).
Unset
Explicitly remove the field when the model supports unset.
Unknown
Field is omitted / unknown in a partial patch input.
Implementations
Sourceimpl MutationAssignment
impl MutationAssignment
Sourcepub fn set(expression: MutationExpression) -> Self
pub fn set(expression: MutationExpression) -> Self
Construct a set assignment.
Sourcepub fn rewrite_with(
&self,
bind_input_path: &dyn Fn(&[String], &ProjectionValueType) -> Result<ProjectionExpression, MutationProgramError>,
) -> Result<Option<ProjectionAssignment>, MutationProgramError>
pub fn rewrite_with( &self, bind_input_path: &dyn Fn(&[String], &ProjectionValueType) -> Result<ProjectionExpression, MutationProgramError>, ) -> Result<Option<ProjectionAssignment>, MutationProgramError>
Rewrite into a projection assignment. Unknown becomes omitted (caller filters).
Errors
Propagates rewrite failures from nested expressions.