MutationProgramError

Enum MutationProgramError 

#[non_exhaustive]
pub enum MutationProgramError {
Show 20 variants EmptyName(&'static str), ZeroVersion(&'static str), InvalidProgramId, PathTooDeep { segments: usize, max: usize, }, ExpressionTooDeep { depth: usize, max: usize, }, TooManyOperations { count: usize, max: usize, }, ValueTooLarge { kind: &'static str, len: usize, max: usize, }, DuplicateOrdinal { kind: &'static str, ordinal: u32, }, NonContiguousOrdinal { kind: &'static str, expected: u32, actual: u32, }, DuplicateName { kind: &'static str, name: String, }, RequiredValueAbsent { path: String, }, UnsetNotAllowed { field: String, }, InvalidKeyValue { field: String, }, InvalidOperation { operation: String, reason: String, }, AmbiguousMutation { model: String, reason: String, }, InvalidReturning { reason: String, }, InvalidConflictTarget { reason: String, }, CanonicalJson(String), MissingInput { path: String, }, Adapter(String),
}
A typed validation, binding, or interpretation failure for a mutation program.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


EmptyName(&'static str)

A stable name, identifier, field, or storage name was empty.



ZeroVersion(&'static str)

A declared version must be non-zero.



InvalidProgramId

A mutation program ID was not in canonical form.



PathTooDeep

An input path exceeded the portable segment limit.

Fields

segments: usize

Observed segment count.

max: usize

Supported segment ceiling.



ExpressionTooDeep

A portable expression or constant exceeded the nesting limit.

Fields

depth: usize

Observed nesting depth.

max: usize

Supported nesting ceiling.



TooManyOperations

A program declared too many operations.

Fields

count: usize

Observed operation count.

max: usize

Supported operation ceiling.



ValueTooLarge

A key, partition, or other bounded canonical value was too large.

Fields

kind: &'static str

Kind of bounded logical encoding.

len: usize

Observed encoded byte length.

max: usize

Supported byte ceiling.



DuplicateOrdinal

Two declarations used the same explicit ordinal.

Fields

kind: &'static str

Kind of ordered declaration.

ordinal: u32

Repeated ordinal.



NonContiguousOrdinal

Ordinals did not form a contiguous zero-based sequence.

Fields

kind: &'static str

Kind of ordered declaration.

expected: u32

Required next ordinal.

actual: u32

Observed ordinal.



DuplicateName

Two declarations used the same stable name.

Fields

kind: &'static str

Kind of named declaration.

name: String

Repeated name.



RequiredValueAbsent

A required expression evaluated as absent.

Fields

path: String

Stable expression or field description.



UnsetNotAllowed

unset appeared where the operation cannot represent it.

Fields

field: String

Field or expression position.



InvalidKeyValue

A key component was null, absent, unset, or structurally invalid.

Fields

field: String

Key component name.



InvalidOperation

An operation shape was incompatible with its semantic kind.

Fields

operation: String

Stable operation identifier.

reason: String

Validation reason.



AmbiguousMutation

Two operations could not deterministically become one final mutation.

Fields

model: String

Affected logical model.

reason: String

Validation reason.



InvalidReturning

Returning selection was empty or ambiguous.

Fields

reason: String

Validation reason.



InvalidConflictTarget

Conflict target was incomplete or unknown.

Fields

reason: String

Validation reason.



CanonicalJson(String)

Canonical JSON encoding failed.



MissingInput

A bound input path was missing from the supplied input object.

Fields

path: String

Missing input path.



Adapter(String)

A binding or interpreter failed while adapting to projection IR.