pub struct ResolvedProjectionKey { /* private fields */ }Expand description
A concrete complete key with its bounded canonical encoding.
Implementations
Sourceimpl ResolvedProjectionKey
impl ResolvedProjectionKey
Sourcepub fn fields(&self) -> &[ResolvedProjectionKeyField]
pub fn fields(&self) -> &[ResolvedProjectionKeyField]
Return components in explicit ordinal order.
Sourcepub fn canonical_bytes(&self) -> &[u8] ⓘ
pub fn canonical_bytes(&self) -> &[u8] ⓘ
Return the bounded domain-separated canonical key encoding.
This is a portable logical encoding, not a physical ORM key encoding.