Module table

Module table 

Neutral table/row primitives shared by read models and operational tables.

The read-model ORM introduced these structures first, but they are not inherently read-model concepts. Outbox storage, inbox/checkpoint tables, and future operational tables can use the same schema and row-write vocabulary.

Re-exports

pub use crate::read_model::ColumnDef as TableColumn;
pub use crate::read_model::ColumnType;
pub use crate::read_model::DeleteRowMutation as DeleteTableRowMutation;
pub use crate::read_model::ExpectedVersion;
pub use crate::read_model::ForeignKey;
pub use crate::read_model::IndexDef as TableIndex;
pub use crate::read_model::PatchMode;
pub use crate::read_model::PatchRowMutation as PatchTableRowMutation;
pub use crate::read_model::PrimaryKey;
pub use crate::read_model::ReadModelAdapterCapabilities as TableAdapterCapabilities;
pub use crate::read_model::ReadModelCommitOutcome as TableCommitOutcome;
pub use crate::read_model::ReadModelError as TableStoreError;
pub use crate::read_model::ReadModelMigrationArtifact as TableMigrationArtifact;
pub use crate::read_model::ReadModelMutation as TableMutation;
pub use crate::read_model::ReadModelSchema as TableSchema;
pub use crate::read_model::ReadModelSchemaAdapter as TableSchemaAdapter;
pub use crate::read_model::ReadModelSchemaAdapterCapabilities as TableSchemaAdapterCapabilities;
pub use crate::read_model::ReadModelSchemaBootstrap as TableSchemaBootstrap;
pub use crate::read_model::ReadModelSchemaIssue as TableSchemaIssue;
pub use crate::read_model::ReadModelSchemaIssueKind as TableSchemaIssueKind;
pub use crate::read_model::ReadModelSchemaRegistry as TableSchemaRegistry;
pub use crate::read_model::ReadModelSchemaVerification as TableSchemaVerification;
pub use crate::read_model::ReadModelWritePlan as TableWritePlan;
pub use crate::read_model::RelationshipDef;
pub use crate::read_model::RelationshipKind;
pub use crate::read_model::RowKey;
pub use crate::read_model::RowMutation as TableRowMutation;
pub use crate::read_model::RowPatch;
pub use crate::read_model::RowValue;
pub use crate::read_model::RowValues;
pub use crate::read_model::RowWriteMode;
pub use crate::read_model::DEFAULT_READ_MODEL_VERSION_COLUMN as DEFAULT_TABLE_VERSION_COLUMN;

Structs

TableSqlSchemaAdapter
Stateless adapter for generating SQL artifacts from table schemas.

Enums

TableSqlDialect
SQL dialect used to render table-schema migration artifacts.

Traits

TableModel
Opt-in trait for non-read-model types that map to a relational table row.
TableSchemaRegistryExt
Extension methods for registering neutral table models.

Functions

generate_table_migration_artifacts
table_schema_bootstrap_result
table_schema_statements