Structs
- Bitcode
Payload Codec - Default payload codec.
- Entity
- Event
Record - Replayable aggregate event record stored in an event-sourced entity stream.
- Event
Record Error - Error when serializing or deserializing event records.
- Event
Upcaster - A stateless, pure transformation that converts an event payload from one version to another.
- Local
Event
Enums
- Upcast
Error - Error returned when an upcaster chain cannot make safe forward progress.
Constants
Traits
- Committable
- Trait for types that can be committed to a repository.
- Event
- Payload
Codec - Codec used to serialize and deserialize event payload bytes.
Functions
- upcast_
events - Apply upcasters to a list of events. Chains automatically (v1->v2->v3).
- upcast_
payload - Decode an event payload, transform it with typed Rust values, and encode the result.