pub struct BusOutboxPublishHook<S, P> { /* private fields */ }Expand description
Publishes committed outbox rows through publisher and settles their claims
in store. The store must be the same outbox store the commit wrote to.
Implementations